package oniguruma
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oniguruma.RegionSource
Match results.
The capture groups returned by a search or match.
capture_beg region idx gets the string position of the capture at the index. The capture at index 0 is the entire match. The string position is an offset in bytes. Returns -1 if the capture group wasn't found. Raises Invalid_argument if the index is out of bounds.
capture_end region idx gets the string position of the capture at the index. The capture at index 0 is the entire match. The string position is an offset in bytes. Returns -1 if the capture group wasn't found. Raises Invalid_argument if the index is out of bounds.